==> mysql-workbench-gpl-5.2.30-src.tar.gz: mysql-workbench-gpl-5.2.30-src/library/forms/cocoa/MFMForms.mm <==
//
//  cf_mforms.mm
//  MySQLWorkbench
//
//  Created by Alfredo Kojima on 21/Jan/09.
//  Copyright 2009 Sun Microsystems Inc. All rights reserved.
//

#import "MFMForms.h"
#include "mforms.h"

extern void cf_view_init();
extern void cf_form_init();
extern void cf_button_init();
extern void cf_box_init();
extern void cf_table_init();
extern void cf_textentry_init();
extern void cf_label_init();
extern void cf_textbox_init();
//moved to WBExtras because it uses WBTabView extern void cf_tabview_init();
extern void cf_checkbox_init();
extern void cf_panel_init();
extern void cf_selector_init();
extern void cf_radiobutton_init();
extern void cf_imagebox_init();
extern void cf_progressbar_init();
extern void cf_filechooser_init();
extern void cf_scrollpanel_init();
extern void cf_listbox_init();
extern void cf_treeview_init();
extern void cf_wizard_init();
extern void cf_util_init();
extern void cf_drawbox_init();
extern void cf_splitter_init();
extern void cf_webbrowser_init();
extern void cf_popup_init();
extern void cf_menu_init();

extern "C" {
void mforms_cocoa_init()
{
  cf_view_init();
  cf_form_init();
  cf_button_init();
  cf_box_init();
  cf_table_init();
  cf_textentry_init();
  cf_label_init();
  cf_textbox_init();
//  cf_tabview_init();
  cf_checkbox_init();
  cf_panel_init();
  cf_selector_init();
  cf_radiobutton_init();
  cf_imagebox_init();
  cf_progressbar_init();
  cf_filechooser_init();
  cf_scrollpanel_init();
  cf_listbox_init();
  cf_treeview_init();
  cf_splitter_init();
  cf_drawbox_init();
  cf_webbrowser_init();
  cf_popup_init();
  cf_menu_init();

  cf_wizard_init();
  
  cf_util_init();
}
  
  
void mforms_cocoa_check()
{
  mforms::ControlFactory::get_instance()->check_impl();
}
};

==> mysql-workbench-gpl-5.2.33-src.tar.gz: mysql-workbench-gpl-5.2.33-src/library/forms/cocoa/MFMForms.mm <==
/* 
 * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */


#import "MFMForms.h"
#include "mforms.h"

extern void cf_view_init();
extern void cf_form_init();
extern void cf_button_init();
extern void cf_box_init();
extern void cf_table_init();
extern void cf_textentry_init();
extern void cf_label_init();
extern void cf_textbox_init();
//moved to WBExtras because it uses WBTabView extern void cf_tabview_init();
extern void cf_checkbox_init();
extern void cf_panel_init();
extern void cf_selector_init();
extern void cf_radiobutton_init();
extern void cf_imagebox_init();
extern void cf_progressbar_init();
extern void cf_filechooser_init();
extern void cf_scrollpanel_init();
extern void cf_listbox_init();
extern void cf_treeview_init();
extern void cf_wizard_init();
extern void cf_util_init();
extern void cf_drawbox_init();
extern void cf_splitter_init();
extern void cf_webbrowser_init();
extern void cf_popup_init();
extern void cf_menu_init();
extern void cf_codeeditor_init();
extern void cf_menubar_init();
extern void cf_toolbar_init();

extern "C" {
void mforms_cocoa_init()
{
  cf_view_init();
  cf_form_init();
  cf_button_init();
  cf_box_init();
  cf_table_init();
  cf_textentry_init();
  cf_label_init();
  cf_textbox_init();
//  cf_tabview_init();
  cf_checkbox_init();
  cf_panel_init();
  cf_selector_init();
  cf_radiobutton_init();
  cf_imagebox_init();
  cf_progressbar_init();
  cf_filechooser_init();
  cf_scrollpanel_init();
  cf_listbox_init();
  cf_treeview_init();
  cf_splitter_init();
  cf_drawbox_init();
  cf_webbrowser_init();
  cf_popup_init();
  cf_menu_init();
  cf_codeeditor_init();

  cf_wizard_init();
  
  cf_util_init();
  cf_menubar_init();
  cf_toolbar_init();
}
  
  
void mforms_cocoa_check()
{
  mforms::ControlFactory::get_instance()->check_impl();
}
};
